==> odata-client-msgraph-beta-0.1.26-sources.jar: odata/msgraph/client/beta/entity/request/RequestRequest.java <==
package odata.msgraph.client.beta.entity.request;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonIgnoreType;
import com.github.davidmoten.odata.client.ActionRequestNoReturn;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.EntityRequest;
import com.github.davidmoten.odata.client.annotation.Action;
import com.github.davidmoten.odata.client.internal.Checks;
import com.github.davidmoten.odata.client.internal.ParameterMap;
import com.github.davidmoten.odata.client.internal.TypedObject;

import java.util.Map;

import odata.msgraph.client.beta.entity.Request;
import odata.msgraph.client.beta.schema.SchemaInfo;

@JsonIgnoreType
public class RequestRequest extends EntityRequest<Request> {

    public RequestRequest(ContextPath contextPath) {
        super(Request.class, contextPath, SchemaInfo.INSTANCE);
    }

    public ApprovalRequest approval() {
        return new ApprovalRequest(contextPath.addSegment("approval"));
    }

    @Action(name = "stop")
    @JsonIgnore
    public ActionRequestNoReturn stop() {
        Map<String, TypedObject> _parameters = ParameterMap.empty();
        return new ActionRequestNoReturn(this.contextPath.addActionOrFunctionSegment("microsoft.graph.stop"), _parameters);
    }

    @Action(name = "recordDecisions")
    @JsonIgnore
    public ActionRequestNoReturn recordDecisions(String reviewResult, String justification) {
        Map<String, TypedObject> _parameters = ParameterMap
            .put("reviewResult", "Edm.String", Checks.checkIsAscii(reviewResult))
            .put("justification", "Edm.String", Checks.checkIsAscii(justification))
            .build();
        return new ActionRequestNoReturn(this.contextPath.addActionOrFunctionSegment("microsoft.graph.recordDecisions"), _parameters);
    }

}

==> odata-client-msgraph-beta-0.2.1-sources.jar: odata/msgraph/client/beta/entity/request/RequestRequest.java <==
package odata.msgraph.client.beta.entity.request;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonIgnoreType;
import com.github.davidmoten.odata.client.ActionRequestNoReturn;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.EntityRequest;
import com.github.davidmoten.odata.client.annotation.Action;
import com.github.davidmoten.odata.client.internal.Checks;
import com.github.davidmoten.odata.client.internal.ParameterMap;
import com.github.davidmoten.odata.client.internal.TypedObject;

import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.Optional;

import odata.msgraph.client.beta.entity.Request;

@JsonIgnoreType
public class RequestRequest extends EntityRequest<Request> {

    public RequestRequest(ContextPath contextPath, Optional<Object> value) {
        super(Request.class, contextPath, value, false);
    }

    @Action(name = "stop")
    @JsonIgnore
    public ActionRequestNoReturn stop() {
        Map<String, TypedObject> _parameters = ParameterMap.empty();
        return new ActionRequestNoReturn(this.contextPath.addActionOrFunctionSegment("microsoft.graph.stop"), _parameters);
    }

    @Action(name = "recordDecisions")
    @JsonIgnore
    public ActionRequestNoReturn recordDecisions(String reviewResult, String justification) {
        Map<String, TypedObject> _parameters = ParameterMap
            .put("reviewResult", "Edm.String", Checks.checkIsAscii(reviewResult))
            .put("justification", "Edm.String", Checks.checkIsAscii(justification))
            .build();
        return new ActionRequestNoReturn(this.contextPath.addActionOrFunctionSegment("microsoft.graph.recordDecisions"), _parameters);
    }

}
